# PAYWIX

paywix is a payment gateway wrapper for Django based applications, currently it's supporting following payment gateways
  - Payu

### Installation
* Python > 3 Version

```python
1. pip install paywix
2. pipenv install paywix
```

### Plugins

Paywix is currently extended with the following plugins. Instructions on how to use them in your own application are detailed below.

| Plugin | README |
| ------ | ------ |
| PAYU | https://github.com/renjithsraj/paywix/blob/master/PAYU.md 

### Todos
 - Paytm
 - Cashfree
 - Stripe
 - Braintree
 - CCavenue

License
----

MIT

